@@ -65,7 +65,11 @@ func runInit(shellName string) {
 	shell.Transient = cfg.TransientPrompt != nil
 	shell.ErrorLine = cfg.ErrorLine != nil || cfg.ValidLine != nil
 	shell.Tooltips = len(cfg.Tooltips) > 0
-	for _, block := range cfg.Blocks {
+	for i, block := range cfg.Blocks {
+		// only fetch cursor position when relevant
+		if i == 0 && block.Newline {
+			shell.Cursor = true
+		}
 		if block.Type == engine.RPrompt {
 			shell.RPrompt = true
 		}
