@@ -67,7 +67,7 @@ func (e *Engine) PrintPrimary() string {
 		var cancelNewline bool
 		if i == 0 {
 			row, _ := e.Env.CursorPosition()
-			cancelNewline = e.Env.Flags().PromptCount == 1 || row == 1
+			cancelNewline = e.Env.Flags().Cleared || e.Env.Flags().PromptCount == 1 || row == 1
 		}
 		e.renderBlock(block, cancelNewline)
 	}
@@ -154,9 +154,14 @@ func (e *Engine) getTitleTemplateText() string {
 
 func (e *Engine) renderBlock(block *Block, cancelNewline bool) {
 	defer func() {
-		e.write(e.Writer.ClearAfter())
+		// when in PowerShell, we need to clear the line after the prompt
+		// to avoid the background being printed on the next line
+		// when at the end of the buffer.
+		// See https://github.com/JanDeDobbeleer/oh-my-posh/issues/65
+		if e.Env.Shell() == shell.PWSH || e.Env.Shell() == shell.PWSH5 {
+			e.write(e.Writer.ClearAfter())
+		}
 	}()
-
 	// when in bash, for rprompt blocks we need to write plain
 	// and wrap in escaped mode or the prompt will not render correctly
 	if e.Env.Shell() == shell.BASH && block.Type == RPrompt {
@@ -374,7 +379,6 @@ func (e *Engine) PrintTooltip(tip string) string {
 			return ""
 		}
 		text, length := block.RenderSegments()
-		e.write(e.Writer.ClearAfter())
 		e.write(e.Writer.CarriageForward())
 		e.write(e.Writer.GetCursorForRightWrite(length, 0))
 		e.write(text)
