@@ -59,6 +59,7 @@ func (env *Shell) TerminalWidth() (int, error) {
 func (env *Shell) Platform() string {
 	const key = "environment_platform"
 	if val, found := env.Cache().Get(key); found {
+		env.Debug(val)
 		return val
 	}
 	var platform string
@@ -67,6 +68,7 @@ func (env *Shell) Platform() string {
 	}()
 	if wsl := env.Getenv("WSL_DISTRO_NAME"); len(wsl) != 0 {
 		platform = strings.Split(strings.ToLower(wsl), "-")[0]
+		env.Debug(platform)
 		return platform
 	}
 	platform, _, _, _ = host.PlatformInformation()
