@@ -40,6 +40,7 @@ var (
 	ErrorLine bool
 	Tooltips  bool
 	RPrompt   bool
+	Cursor    bool
 )
 
 func getExecutablePath(env platform.Environment) (string, error) {
@@ -228,6 +229,7 @@ func PrintInit(env platform.Environment) string {
 		"::ERROR_LINE::", toggleSetting(ErrorLine),
 		"::TOOLTIPS::", toggleSetting(Tooltips),
 		"::RPROMPT::", strconv.FormatBool(RPrompt),
+		"::CURSOR::", strconv.FormatBool(Cursor),
 	).Replace(script)
 }
 
