@@ -127,7 +127,7 @@ module.exports = {
       copyright: `Copyright © ${new Date().getFullYear()} <a href='https://github.com/sponsors/JanDeDobbeleer' target='_blank'>Jan De Dobbeleer</a> and <a href='/docs/contributors'>contributors</a>.`,
     },
     appInsights: {
-      instrumentationKey: '72804848-dc30-4856-8245-4fa1450b041f',
+      instrumentationKey: '51741aa7-e087-4e80-b7b0-0863d467462a',
     },
     algolia: {
       appId: 'XIR4RB3TM1',
